/****************************************************************************
** Meta object code from reading C++ file 'Positioner.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../union-6.7.4/src/output/qtquick/plugin/Positioner.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Positioner.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5Union5Quick10PositionerE_t {};
} // unnamed namespace

template <> constexpr inline auto Union::Quick::Positioner::qt_create_metaobjectdata<qt_meta_tag_ZN5Union5Quick10PositionerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Union::Quick::Positioner",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Attached Property",
        "QML.Attached",
        "Positioner",
        "positionItemsChanged",
        "",
        "implicitWidthChanged",
        "implicitHeightChanged",
        "debugChanged",
        "layoutDirectionChanged",
        "positionItems",
        "ItemList",
        "implicitWidth",
        "implicitHeight",
        "debug",
        "layoutDirection",
        "Qt::LayoutDirection"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'positionItemsChanged'
        QtMocHelpers::SignalData<void()>(9, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'implicitWidthChanged'
        QtMocHelpers::SignalData<void()>(11, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'implicitHeightChanged'
        QtMocHelpers::SignalData<void()>(12, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'debugChanged'
        QtMocHelpers::SignalData<void()>(13, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'layoutDirectionChanged'
        QtMocHelpers::SignalData<void()>(14, 10, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'positionItems'
        QtMocHelpers::PropertyData<ItemList>(15, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'implicitWidth'
        QtMocHelpers::PropertyData<qreal>(17, QMetaType::QReal, QMC::DefaultPropertyFlags, 1),
        // property 'implicitHeight'
        QtMocHelpers::PropertyData<qreal>(18, QMetaType::QReal, QMC::DefaultPropertyFlags, 2),
        // property 'debug'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'layoutDirection'
        QtMocHelpers::PropertyData<Qt::LayoutDirection>(20, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 4),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    8 },
    });
    return QtMocHelpers::metaObjectData<Positioner, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Union::Quick::Positioner::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Union5Quick10PositionerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Union5Quick10PositionerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5Union5Quick10PositionerE_t>.metaTypes,
    nullptr
} };

void Union::Quick::Positioner::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Positioner *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->positionItemsChanged(); break;
        case 1: _t->implicitWidthChanged(); break;
        case 2: _t->implicitHeightChanged(); break;
        case 3: _t->debugChanged(); break;
        case 4: _t->layoutDirectionChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Positioner::*)()>(_a, &Positioner::positionItemsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Positioner::*)()>(_a, &Positioner::implicitWidthChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Positioner::*)()>(_a, &Positioner::implicitHeightChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Positioner::*)()>(_a, &Positioner::debugChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Positioner::*)()>(_a, &Positioner::layoutDirectionChanged, 4))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<ItemList*>(_v) = _t->positionItems(); break;
        case 1: *reinterpret_cast<qreal*>(_v) = _t->implicitWidth(); break;
        case 2: *reinterpret_cast<qreal*>(_v) = _t->implicitHeight(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->debug(); break;
        case 4: *reinterpret_cast<Qt::LayoutDirection*>(_v) = _t->layoutDirection(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setPositionItems(*reinterpret_cast<ItemList*>(_v)); break;
        case 3: _t->setDebug(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setLayoutDirection(*reinterpret_cast<Qt::LayoutDirection*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Union::Quick::Positioner::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Union::Quick::Positioner::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Union5Quick10PositionerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Union::Quick::Positioner::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void Union::Quick::Positioner::positionItemsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Union::Quick::Positioner::implicitWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Union::Quick::Positioner::implicitHeightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Union::Quick::Positioner::debugChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Union::Quick::Positioner::layoutDirectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
namespace {
struct qt_meta_tag_ZN5Union5Quick14PositionedItemE_t {};
} // unnamed namespace

template <> constexpr inline auto Union::Quick::PositionedItem::qt_create_metaobjectdata<qt_meta_tag_ZN5Union5Quick14PositionedItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Union::Quick::PositionedItem",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Attached Property",
        "QML.Attached",
        "PositionedItem",
        "sourceChanged",
        "",
        "horizontalAlignmentChanged",
        "verticalAlignmentChanged",
        "minimumWidthChanged",
        "minimumHeightChanged",
        "positionChildren",
        "source",
        "Union::Quick::PositionerSource::Source",
        "horizontalAlignment",
        "Union::Properties::Alignment",
        "verticalAlignment",
        "minimumWidth",
        "minimumHeight"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sourceChanged'
        QtMocHelpers::SignalData<void()>(9, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'horizontalAlignmentChanged'
        QtMocHelpers::SignalData<void()>(11, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'verticalAlignmentChanged'
        QtMocHelpers::SignalData<void()>(12, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'minimumWidthChanged'
        QtMocHelpers::SignalData<void()>(13, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'minimumHeightChanged'
        QtMocHelpers::SignalData<void()>(14, 10, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'positionChildren'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'source'
        QtMocHelpers::PropertyData<Union::Quick::PositionerSource::Source>(16, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'horizontalAlignment'
        QtMocHelpers::PropertyData<Union::Properties::Alignment>(18, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'verticalAlignment'
        QtMocHelpers::PropertyData<Union::Properties::Alignment>(20, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'minimumWidth'
        QtMocHelpers::PropertyData<qreal>(21, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::StdCppSet, 3),
        // property 'minimumHeight'
        QtMocHelpers::PropertyData<qreal>(22, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::StdCppSet, 4),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    8 },
    });
    return QtMocHelpers::metaObjectData<PositionedItem, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN5Union5Quick14PositionedItemE[] = {
    QMetaObject::SuperData::link<Union::Quick::PositionerSource::staticMetaObject>(),
    QMetaObject::SuperData::link<Union::Properties::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject Union::Quick::PositionedItem::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Union5Quick14PositionedItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Union5Quick14PositionedItemE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN5Union5Quick14PositionedItemE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5Union5Quick14PositionedItemE_t>.metaTypes,
    nullptr
} };

void Union::Quick::PositionedItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PositionedItem *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sourceChanged(); break;
        case 1: _t->horizontalAlignmentChanged(); break;
        case 2: _t->verticalAlignmentChanged(); break;
        case 3: _t->minimumWidthChanged(); break;
        case 4: _t->minimumHeightChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PositionedItem::*)()>(_a, &PositionedItem::sourceChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PositionedItem::*)()>(_a, &PositionedItem::horizontalAlignmentChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PositionedItem::*)()>(_a, &PositionedItem::verticalAlignmentChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PositionedItem::*)()>(_a, &PositionedItem::minimumWidthChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (PositionedItem::*)()>(_a, &PositionedItem::minimumHeightChanged, 4))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->positionChildren(); break;
        case 1: *reinterpret_cast<Union::Quick::PositionerSource::Source*>(_v) = _t->source(); break;
        case 2: *reinterpret_cast<Union::Properties::Alignment*>(_v) = _t->horizontalAlignment(); break;
        case 3: *reinterpret_cast<Union::Properties::Alignment*>(_v) = _t->verticalAlignment(); break;
        case 4: *reinterpret_cast<qreal*>(_v) = _t->minimumWidth(); break;
        case 5: *reinterpret_cast<qreal*>(_v) = _t->minimumHeight(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setPositionChildren(*reinterpret_cast<bool*>(_v)); break;
        case 1: _t->setSource(*reinterpret_cast<Union::Quick::PositionerSource::Source*>(_v)); break;
        case 2: _t->setHorizontalAlignment(*reinterpret_cast<Union::Properties::Alignment*>(_v)); break;
        case 3: _t->setVerticalAlignment(*reinterpret_cast<Union::Properties::Alignment*>(_v)); break;
        case 4: _t->setMinimumWidth(*reinterpret_cast<qreal*>(_v)); break;
        case 5: _t->setMinimumHeight(*reinterpret_cast<qreal*>(_v)); break;
        default: break;
        }
    }
    if (_c == QMetaObject::ResetProperty) {
        switch (_id) {
        case 2: _t->resetHorizontalAlignment(); break;
        case 3: _t->resetVerticalAlignment(); break;
        case 4: _t->resetMinimumWidth(); break;
        case 5: _t->resetMinimumWidth(); break;
        default: break;
        }
    }
}

const QMetaObject *Union::Quick::PositionedItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Union::Quick::PositionedItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Union5Quick14PositionedItemE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Union::Quick::PositionedItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void Union::Quick::PositionedItem::sourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Union::Quick::PositionedItem::horizontalAlignmentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Union::Quick::PositionedItem::verticalAlignmentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Union::Quick::PositionedItem::minimumWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Union::Quick::PositionedItem::minimumHeightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
namespace {
struct qt_meta_tag_ZN5Union5Quick16PositionerSourceE_t {};
} // unnamed namespace

template <> constexpr inline auto Union::Quick::PositionerSource::qt_create_metaobjectdata<qt_meta_tag_ZN5Union5Quick16PositionerSourceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Union::Quick::PositionerSource",
        "QML.Element",
        "auto",
        "Source",
        "Layout",
        "Text",
        "Icon"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Source'
        QtMocHelpers::EnumData<Source>(3, 3, QMC::EnumIsScoped).add({
            {    4, Source::Layout },
            {    5, Source::Text },
            {    6, Source::Icon },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN5Union5Quick16PositionerSourceE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}

static constexpr auto qt_staticMetaObjectContent_ZN5Union5Quick16PositionerSourceE =
    Union::Quick::PositionerSource::qt_create_metaobjectdata<qt_meta_tag_ZN5Union5Quick16PositionerSourceE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN5Union5Quick16PositionerSourceE =
    qt_staticMetaObjectContent_ZN5Union5Quick16PositionerSourceE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN5Union5Quick16PositionerSourceE =
    qt_staticMetaObjectContent_ZN5Union5Quick16PositionerSourceE.relocatingData;

Q_CONSTINIT const QMetaObject Union::Quick::PositionerSource::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN5Union5Quick16PositionerSourceE.stringdata,
    qt_staticMetaObjectStaticContent_ZN5Union5Quick16PositionerSourceE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN5Union5Quick16PositionerSourceE.metaTypes,
    nullptr
} };

QT_WARNING_POP
