/****************************************************************************
** Meta object code from reading C++ file 'Types.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../union-6.7.4/src/output/qtquick/plugin/Types.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Types.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5Union5Quick9AlignmentE_t {};
} // unnamed namespace

template <> constexpr inline auto Union::Quick::Alignment::qt_create_metaobjectdata<qt_meta_tag_ZN5Union5Quick9AlignmentE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Union::Quick::Alignment",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "toQtHorizontal",
        "Qt::Alignment",
        "",
        "Union::Quick::Alignment::AlignmentType",
        "alignment",
        "toQtVertical",
        "AlignmentType",
        "Unspecified",
        "Start",
        "Center",
        "End",
        "Fill",
        "StackCenter",
        "StackFill"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'toQtHorizontal'
        QtMocHelpers::MethodData<Qt::Alignment(Union::Quick::Alignment::AlignmentType)>(5, 7, QMC::AccessPublic, 0x80000000 | 6, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Method 'toQtVertical'
        QtMocHelpers::MethodData<Qt::Alignment(Union::Quick::Alignment::AlignmentType)>(10, 7, QMC::AccessPublic, 0x80000000 | 6, {{
            { 0x80000000 | 8, 9 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'AlignmentType'
        QtMocHelpers::EnumData<enum AlignmentType>(11, 11, QMC::EnumFlags{}).add({
            {   12, AlignmentType::Unspecified },
            {   13, AlignmentType::Start },
            {   14, AlignmentType::Center },
            {   15, AlignmentType::End },
            {   16, AlignmentType::Fill },
            {   17, AlignmentType::StackCenter },
            {   18, AlignmentType::StackFill },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<Alignment, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Union::Quick::Alignment::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Union5Quick9AlignmentE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Union5Quick9AlignmentE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5Union5Quick9AlignmentE_t>.metaTypes,
    nullptr
} };

void Union::Quick::Alignment::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Alignment *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { Qt::Alignment _r = _t->toQtHorizontal((*reinterpret_cast<std::add_pointer_t<Union::Quick::Alignment::AlignmentType>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Qt::Alignment*>(_a[0]) = std::move(_r); }  break;
        case 1: { Qt::Alignment _r = _t->toQtVertical((*reinterpret_cast<std::add_pointer_t<Union::Quick::Alignment::AlignmentType>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Qt::Alignment*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *Union::Quick::Alignment::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Union::Quick::Alignment::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Union5Quick9AlignmentE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Union::Quick::Alignment::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN5Union5Quick5SizesE_t {};
} // unnamed namespace

template <> constexpr inline auto Union::Quick::Sizes::qt_create_metaobjectdata<qt_meta_tag_ZN5Union5Quick5SizesE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Union::Quick::Sizes",
        "QML.Element",
        "sizes",
        "left",
        "right",
        "top",
        "bottom",
        "valid"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'left'
        QtMocHelpers::PropertyData<qreal>(3, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'right'
        QtMocHelpers::PropertyData<qreal>(4, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'top'
        QtMocHelpers::PropertyData<qreal>(5, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'bottom'
        QtMocHelpers::PropertyData<qreal>(6, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'valid'
        QtMocHelpers::PropertyData<bool>(7, QMetaType::Bool, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<Sizes, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Union::Quick::Sizes::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Union5Quick5SizesE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Union5Quick5SizesE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5Union5Quick5SizesE_t>.metaTypes,
    nullptr
} };

void Union::Quick::Sizes::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<Sizes *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<qreal*>(_v) = _t->left(); break;
        case 1: *reinterpret_cast<qreal*>(_v) = _t->right(); break;
        case 2: *reinterpret_cast<qreal*>(_v) = _t->top(); break;
        case 3: *reinterpret_cast<qreal*>(_v) = _t->bottom(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isValid(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setLeft(*reinterpret_cast<qreal*>(_v)); break;
        case 1: _t->setRight(*reinterpret_cast<qreal*>(_v)); break;
        case 2: _t->setTop(*reinterpret_cast<qreal*>(_v)); break;
        case 3: _t->setBottom(*reinterpret_cast<qreal*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN5Union5Quick8ColorSetE_t {};
} // unnamed namespace

template <> constexpr inline auto Union::Quick::ColorSet::qt_create_metaobjectdata<qt_meta_tag_ZN5Union5Quick8ColorSetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Union::Quick::ColorSet",
        "QML.Element",
        "auto",
        "QML.Foreign",
        "Union::Element",
        "QML.ForeignIsNamespace",
        "true"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN5Union5Quick8ColorSetE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}

static constexpr auto qt_staticMetaObjectContent_ZN5Union5Quick8ColorSetE =
    Union::Quick::ColorSet::qt_create_metaobjectdata<qt_meta_tag_ZN5Union5Quick8ColorSetE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN5Union5Quick8ColorSetE =
    qt_staticMetaObjectContent_ZN5Union5Quick8ColorSetE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN5Union5Quick8ColorSetE =
    qt_staticMetaObjectContent_ZN5Union5Quick8ColorSetE.relocatingData;

Q_CONSTINIT const QMetaObject Union::Quick::ColorSet::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN5Union5Quick8ColorSetE.stringdata,
    qt_staticMetaObjectStaticContent_ZN5Union5Quick8ColorSetE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN5Union5Quick8ColorSetE.metaTypes,
    nullptr
} };

QT_WARNING_POP
